@@ -6,6 +6,10 @@
 #' `link_copy()` creates a new link pointing to the same location as the previous link.
 #'
 #' `dir_copy()` copies the directory recursively at the new location.
+#' @details
+#' The behavior of `dir_copy()` differs slightly than that of `file.copy()` when
+#' `overwrite = TRUE`. The directory will always be copied to `new_path`, even
+#' if the name differs from the basename of `path`.
 #' @param new_path A character vector of paths to the new locations.
 #' @param overwrite Overwrite files if they exist. If this is `FALSE` and the
 #'   file exists an error will be thrown.
@@ -64,28 +68,28 @@ file_copy <- function(path, new_path, overwrite = FALSE) {
 
 #' @rdname copy
 #' @export
-dir_copy <- function(path, new_path) {
+dir_copy <- function(path, new_path, overwrite = FALSE) {
   assert_no_missing(path)
   assert_no_missing(new_path)
   assert("`path` must be a directory", all(is_dir(path)))
   assert("Length of `path` must equal length of `new_path`", length(path) == length(new_path))
 
   for (i in seq_along(path)) {
-    if (isTRUE(unname(is_dir(new_path[[i]])))) {
+    if (!isTRUE(overwrite) && isTRUE(unname(is_dir(new_path[[i]])))) {
       new_path[[i]] <- path(new_path[[i]], path_file(path))
     }
     dir_create(new_path[[i]])
 
-    dirs <- dir_ls(path[[i]], type = "directory", recursive = TRUE, all = TRUE)
+    dirs <- dir_ls(path[[i]], type = "directory", recurse = TRUE, all = TRUE)
     dir_create(path(new_path[[i]], path_rel(dirs, path[[i]])))
 
-    files <- dir_ls(path, recursive = TRUE,
+    files <- dir_ls(path, recurse = TRUE,
       type = c("unknown", "file", "FIFO", "socket", "character_device", "block_device"), all = TRUE)
-    file_copy(files, path(new_path[[i]], path_rel(files, path[[i]])))
+    file_copy(files, path(new_path[[i]], path_rel(files, path[[i]])), overwrite = overwrite)
 
-    links <- dir_ls(path, recursive = TRUE,
+    links <- dir_ls(path, recurse = TRUE,
       type = "symlink", all = TRUE)
-    link_copy(links, path(new_path[[i]], path_rel(links, path[[i]])))
+    link_copy(links, path(new_path[[i]], path_rel(links, path[[i]])), overwrite = overwrite)
   }
 
   invisible(path_tidy(new_path))
